@@ -84,26 +84,18 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
     //Set up the title widget...
     KTitleWidget *titleWidget = new KTitleWidget(q);
 
-    QIcon windowIcon;
-    if (!aboutData.programIconName().isEmpty()) {
+    QIcon windowIcon = qApp->windowIcon();
+    if (windowIcon.isNull() && !aboutData.programIconName().isEmpty()) {
         windowIcon = QIcon::fromTheme(aboutData.programIconName());
-    } else {
-        windowIcon = qApp->windowIcon();
     }
-    titleWidget->setPixmap(windowIcon.pixmap(64, 64), KTitleWidget::ImageLeft);
+    titleWidget->setPixmap(windowIcon.pixmap(48, 48), KTitleWidget::ImageLeft);
     if (aboutData.programLogo().canConvert<QPixmap>()) {
         titleWidget->setPixmap(aboutData.programLogo().value<QPixmap>(), KTitleWidget::ImageLeft);
     } else if (aboutData.programLogo().canConvert<QImage>()) {
         titleWidget->setPixmap(QPixmap::fromImage(aboutData.programLogo().value<QImage>()), KTitleWidget::ImageLeft);
     }
 
-    if (opt & HideKdeVersion)
-        titleWidget->setText(i18n("<html><font size=\"5\">%1</font><br /><b>Version %2</b><br />&nbsp;</html>",
-                                  aboutData.displayName(), aboutData.version()));
-    else
-        titleWidget->setText(i18nc("Program name, version and KDE platform version; do not translate 'Development Platform'",
-                                   "<html><font size=\"5\">%1</font><br /><b>Version %2</b><br />Using KDE Frameworks %3</html>",
-                                   aboutData.displayName(), aboutData.version(), QStringLiteral(KXMLGUI_VERSION_STRING)));
+    titleWidget->setText(i18n("<html><font size=\"5\">%1</font></html>", aboutData.displayName()));
 
     //Then the tab bar...
     QTabWidget *tabWidget = new QTabWidget;
@@ -121,7 +113,7 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
     }
 
     if (!aboutData.homepage().isEmpty()) {
-        aboutPageText += QLatin1Char('\n') + QString::fromLatin1("<a href=\"%1\">%1</a>").arg(aboutData.homepage()) + QLatin1Char('\n');
+        aboutPageText += QLatin1Char('\n') + QStringLiteral("<a href=\"%1\">%1</a>").arg(aboutData.homepage()) + QLatin1Char('\n');
     }
     aboutPageText = aboutPageText.trimmed();
 
@@ -140,7 +132,7 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
         const KAboutLicense &license = aboutData.licenses().at(i);
 
         QLabel *showLicenseLabel = new QLabel;
-        showLicenseLabel->setText(QString::fromLatin1("<a href=\"%1\">%2</a>").arg(QString::number(i),
+        showLicenseLabel->setText(QStringLiteral("<a href=\"%1\">%2</a>").arg(QString::number(i),
                                   i18n("License: %1", license.name(KAboutLicense::FullName))));
         showLicenseLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
         connect(showLicenseLabel, SIGNAL(linkActivated(QString)), q, SLOT(_k_showLicense(QString)));
@@ -155,6 +147,26 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
 
     tabWidget->addTab(aboutWidget, i18n("&About"));
 
+    // Version
+    QWidget *versionWidget = new QWidget(q);
+    QVBoxLayout *versionLayout = new QVBoxLayout;
+    QLabel *versionLabel = new QLabel(i18n("<b>Version %1</b>", aboutData.version()));
+    versionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
+    versionLayout->addWidget(versionLabel);
+    if (!(opt & HideKdeVersion)) {
+        QLabel *versionLabel = new QLabel(
+            i18n("Using:<ul><li>KDE Frameworks %1</li><li>Qt %2 (built against %3)</li><li>The <em>%4</em> windowing system</li></ul>",
+                 QStringLiteral(KXMLGUI_VERSION_STRING),
+                 QString::fromLocal8Bit(qVersion()),
+                 QStringLiteral(QT_VERSION_STR),
+                 QGuiApplication::platformName()));
+        versionLabel->setTextInteractionFlags(Qt::TextSelectableByMouse);
+        versionLayout->addWidget(versionLabel);
+    }
+    versionLayout->addStretch();
+    versionWidget->setLayout(versionLayout);
+    tabWidget->addTab(versionWidget, i18n("&Version"));
+
     //Palette needed at least for translators...
     QPalette transparentBackgroundPalette;
     transparentBackgroundPalette.setColor(QPalette::Base, Qt::transparent);
@@ -172,7 +184,7 @@ void KAboutApplicationDialog::Private::init(const KAboutData &ad, Options opt)
             bugsLabel->setContentsMargins(4, 2, 0, 4);
             bugsLabel->setOpenExternalLinks(true);
             if (!aboutData.customAuthorTextEnabled()) {
-                if (aboutData.bugAddress().isEmpty() || aboutData.bugAddress() == QStringLiteral("submit@bugs.kde.org")) {
+                if (aboutData.bugAddress().isEmpty() || aboutData.bugAddress() == QLatin1String("submit@bugs.kde.org")) {
                     bugsLabel->setText(i18n("Please use <a href=\"http://bugs.kde.org\">http://bugs.kde.org</a> to report bugs.\n"));
                 } else {
                     if ((aboutData.authors().count() == 1) &&
