@@ -53,7 +53,7 @@
 
 #include "../kxmlgui_version.h"
 
-static const char *const separatorstring = I18N_NOOP("--- separator ---");
+static const char separatorstring[] = I18N_NOOP("--- separator ---");
 
 #define SEPARATORSTRING i18n(separatorstring)
 
@@ -174,7 +174,14 @@ QString XmlData::toolBarText(const QDomElement &it) const
     if (txt.isEmpty()) {
         name = it.attribute(attrName);
     } else {
-        name = i18n(txt.constData());
+        QByteArray domain = it.namedItem(QStringLiteral("text")).toElement().attribute(QStringLiteral("translationDomain")).toUtf8();
+        if (domain.isEmpty()) {
+            domain = it.ownerDocument().documentElement().attribute(QStringLiteral("translationDomain")).toUtf8();
+            if (domain.isEmpty()) {
+                domain = KLocalizedString::applicationDomain();
+            }
+        }
+        name = i18nd(domain.constData(), txt.constData());
     }
 
     // the name of the toolbar might depend on whether or not
@@ -622,6 +629,10 @@ void KEditToolBarPrivate::init()
                                     | QDialogButtonBox::Ok
                                     | QDialogButtonBox::Apply
                                     | QDialogButtonBox::Cancel);
+    KGuiItem::assign(m_buttonBox->button(QDialogButtonBox::Ok), KStandardGuiItem::ok());
+    KGuiItem::assign(m_buttonBox->button(QDialogButtonBox::Apply), KStandardGuiItem::apply());
+    KGuiItem::assign(m_buttonBox->button(QDialogButtonBox::Cancel), KStandardGuiItem::cancel());
+    KGuiItem::assign(m_buttonBox->button(QDialogButtonBox::RestoreDefaults), KStandardGuiItem::defaults());
     q->connect(m_buttonBox, SIGNAL(clicked(QAbstractButton*)), SLOT(_k_slotButtonClicked(QAbstractButton*)));
     q->connect(m_buttonBox, SIGNAL(rejected()), SLOT(reject()));
     m_layout->addWidget(m_buttonBox);
@@ -700,7 +711,8 @@ void KEditToolBarPrivate::defaultClicked()
         if (slash) {
             m_file = m_file.mid(slash);
         }
-        const QString xml_file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QCoreApplication::instance()->applicationName() + QLatin1Char('/') + m_file;
+        const QString xml_file = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +
+            QStringLiteral("/kxmlgui5/") + QCoreApplication::instance()->applicationName() + QLatin1Char('/') + m_file;
 
         if (QFile::exists(xml_file))
             if (!QFile::remove(xml_file)) {
@@ -920,7 +932,7 @@ bool KEditToolBarWidget::save()
             if (menuElement.isNull()) {
                 continue;
             }
-            menuElement.setAttribute(QStringLiteral("noMerge"), QLatin1String("1"));
+            menuElement.setAttribute(QStringLiteral("noMerge"), QStringLiteral("1"));
         }
 
         //qDebug() << (*it).domDocument().toString();
@@ -1071,12 +1083,12 @@ void KEditToolBarWidgetPrivate::setupLayout()
     QObject::connect(m_upAction, SIGNAL(clicked()), m_widget, SLOT(slotUpButton()));
 
     m_insertAction = new QToolButton(m_widget);
-    m_insertAction->setIcon(QIcon::fromTheme(QApplication::isRightToLeft() ? QStringLiteral("go-previous") : QLatin1String("go-next")));
+    m_insertAction->setIcon(QIcon::fromTheme(QApplication::isRightToLeft() ? QStringLiteral("go-previous") : QStringLiteral("go-next")));
     m_insertAction->setEnabled(false);
     QObject::connect(m_insertAction, SIGNAL(clicked()), m_widget, SLOT(slotInsertButton()));
 
     m_removeAction = new QToolButton(m_widget);
-    m_removeAction->setIcon(QIcon::fromTheme(QApplication::isRightToLeft() ? QStringLiteral("go-next") : QLatin1String("go-previous")));
+    m_removeAction->setIcon(QIcon::fromTheme(QApplication::isRightToLeft() ? QStringLiteral("go-next") : QStringLiteral("go-previous")));
     m_removeAction->setEnabled(false);
     QObject::connect(m_removeAction, SIGNAL(clicked()), m_widget, SLOT(slotRemoveButton()));
 
@@ -1439,7 +1451,7 @@ void KEditToolBarWidgetPrivate::insertActive(ToolBarItem *item, ToolBarItem *bef
     }
 
     // and set this container as a noMerge
-    m_currentToolBarElem.setAttribute(QStringLiteral("noMerge"), QLatin1String("1"));
+    m_currentToolBarElem.setAttribute(QStringLiteral("noMerge"), QStringLiteral("1"));
 
     // update the local doc
     updateLocal(m_currentToolBarElem);
@@ -1461,7 +1473,7 @@ void KEditToolBarWidgetPrivate::removeActive(ToolBarItem *item)
         m_currentToolBarElem.removeChild(elem);
 
         // and set this container as a noMerge
-        m_currentToolBarElem.setAttribute(QStringLiteral("noMerge"), QLatin1String("1"));
+        m_currentToolBarElem.setAttribute(QStringLiteral("noMerge"), QStringLiteral("1"));
 
         // update the local doc
         updateLocal(m_currentToolBarElem);
@@ -1515,7 +1527,7 @@ void KEditToolBarWidgetPrivate::moveActive(ToolBarItem *item, ToolBarItem *befor
     }
 
     // and set this container as a noMerge
-    m_currentToolBarElem.setAttribute(QStringLiteral("noMerge"), QLatin1String("1"));
+    m_currentToolBarElem.setAttribute(QStringLiteral("noMerge"), QStringLiteral("1"));
 
     // update the local doc
     updateLocal(m_currentToolBarElem);
@@ -1654,10 +1666,10 @@ void KEditToolBarWidgetPrivate::slotChangeIconText()
         QDomElement act_elem = KXMLGUIFactory::findActionByName(elem, item->internalName(), true /*create*/);
         Q_ASSERT(!act_elem.isNull());
         if (iconTextChanged) {
-            act_elem.setAttribute(QString::fromLatin1("iconText"), iconText);
+            act_elem.setAttribute(QStringLiteral("iconText"), iconText);
         }
         if (hiddenChanged) {
-            act_elem.setAttribute(QString::fromLatin1("priority"), hidden ? QAction::LowPriority : QAction::NormalPriority);
+            act_elem.setAttribute(QStringLiteral("priority"), hidden ? QAction::LowPriority : QAction::NormalPriority);
         }
 
         // we're modified, so let this change
