@@ -243,7 +243,7 @@ void KKeySequenceWidgetPrivate::wontStealShortcut(QAction *item, const QKeySeque
     QString msg(i18n("<qt>The '%1' key combination is already used by the <b>%2</b> action.<br>"
                      "Please select a different one.</qt>", seq.toString(QKeySequence::NativeText),
                      KLocalizedString::removeAcceleratorMarker(item->text())));
-    KMessageBox::sorry(q, msg);
+    KMessageBox::sorry(q, msg, title);
 }
 
 KKeySequenceWidget::KKeySequenceWidget(QWidget *parent)
@@ -338,7 +338,7 @@ void KKeySequenceWidget::setClearButtonShown(bool show)
     d->clearButton->setVisible(show);
 }
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
 void KKeySequenceWidget::setCheckActionList(const QList<QAction *> &checkList) // deprecated
 {
     d->checkList = checkList;
@@ -692,6 +692,12 @@ bool KKeySequenceButton::event(QEvent *e)
         return true;
     }
 
+    if (d->isRecording && e->type() == QEvent::ContextMenu) {
+        // is caused by Qt::Key_Menu
+        e->accept();
+        return true;
+    }
+
     return QPushButton::event(e);
 }
 
@@ -734,7 +740,8 @@ void KKeySequenceButton::keyPressEvent(QKeyEvent *e)
     case Qt::Key_Control:
     case Qt::Key_Alt:
     case Qt::Key_Meta:
-    case Qt::Key_Menu: //unused (yes, but why?)
+    case Qt::Key_Super_L:
+    case Qt::Key_Super_R:
         d->controlModifierlessTimout();
         d->updateShortcutDisplay();
         break;
