@@ -45,6 +45,7 @@
 #include <QStatusBar>
 #include <QStyle>
 #include <QWidget>
+#include <QWindow>
 #include <QDBusConnection>
 
 #include <ktoggleaction.h>
@@ -59,6 +60,8 @@
 
 //#include <ctype.h>
 
+static const char WINDOW_PROPERTIES[]="WindowProperties";
+
 static QMenuBar *internalMenuBar(KMainWindow *mw)
 {
     return mw->findChild<QMenuBar *>(QString(), Qt::FindDirectChildrenOnly);
@@ -82,7 +85,7 @@ class DockResizeListener : public QObject
 public:
     DockResizeListener(KMainWindow *win);
     virtual ~DockResizeListener();
-    virtual bool eventFilter(QObject *watched, QEvent *event);
+    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
 
 private:
     KMainWindow *m_win;
@@ -124,8 +127,10 @@ KMWSessionManager::~KMWSessionManager()
 {
 }
 
-bool KMWSessionManager::saveState(QSessionManager &)
+bool KMWSessionManager::saveState(QSessionManager &sm)
 {
+    KConfigGui::setSessionConfig(sm.sessionId(), sm.sessionKey());
+
     KConfig *config = KConfigGui::sessionConfig();
     if (KMainWindow::memberList().count()) {
         // According to Jochen Wilhelmy <digisnap@cs.tu-berlin.de>, this
@@ -141,6 +146,19 @@ bool KMWSessionManager::saveState(QSessionManager &)
 
     KConfigGroup group(config, "Number");
     group.writeEntry("NumberOfWindows", n);
+
+    // store new status to disk
+    config->sync();
+
+    // generate discard command for new file
+    QString localFilePath =  QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1Char('/') + config->name();
+    if (QFile::exists(localFilePath)) {
+        QStringList discard;
+        discard << QStringLiteral("rm");
+        discard << localFilePath;
+        sm.setDiscardCommand(discard);
+    }
+
     return true;
 }
 
@@ -161,11 +179,6 @@ KMainWindow::KMainWindow(KMainWindowPrivate &dd, QWidget *parent, Qt::WindowFlag
 
 void KMainWindowPrivate::init(KMainWindow *_q)
 {
-    // We set allow quit to true when the first mainwindow is created, so that when the refcounting
-    // reaches 0 the application can quit. We don't want this to happen before the first mainwindow
-    // is created, otherwise running a job in main would exit the app too early.
-    QCoreApplication::setQuitLockEnabled(true);
-
     q = _q;
 
     q->setAnimated(q->style()->styleHint(QStyle::SH_Widget_Animate, 0, q));
@@ -185,6 +198,19 @@ void KMainWindowPrivate::init(KMainWindow *_q)
 
     sMemberList()->append(q);
 
+    // If application is translated, load translator information for use in
+    // KAboutApplicationDialog or other getters. The context and messages below
+    // both must be exactly as listed, and are forced to be loaded from the
+    // application's own message catalog instead of kxmlgui's.
+    KAboutData aboutData(KAboutData::applicationData());
+    if (aboutData.translators().isEmpty()) {
+        aboutData.setTranslator(
+                i18ndc(Q_NULLPTR, "NAME OF TRANSLATORS", "Your names"),
+                i18ndc(Q_NULLPTR, "EMAIL OF TRANSLATORS", "Your emails"));
+
+        KAboutData::setApplicationData(aboutData);
+    }
+
     settingsDirty = false;
     autoSaveSettings = false;
     autoSaveWindowSize = true; // for compatibility
@@ -215,7 +241,7 @@ static bool endsWithHashNumber(const QString &s)
 
 static inline bool isValidDBusObjectPathCharacter(const QChar &c)
 {
-    register ushort u = c.unicode();
+    ushort u = c.unicode();
     return (u >= QLatin1Char('a') && u <= QLatin1Char('z'))
            || (u >= QLatin1Char('A') && u <= QLatin1Char('Z'))
            || (u >= QLatin1Char('0') && u <= QLatin1Char('9'))
@@ -335,7 +361,7 @@ KMainWindow::~KMainWindow()
     delete k_ptr;
 }
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
 QMenu *KMainWindow::helpMenu(const QString &aboutAppText, bool showWhatsThis)
 {
     K_D(KMainWindow);
@@ -377,8 +403,8 @@ bool KMainWindow::canBeRestored(int number)
         return false;
     }
 
-    KConfigGroup group(config, QStringLiteral("Number"));
-    const int n = group.readEntry(QStringLiteral("NumberOfWindows"), 1);
+    KConfigGroup group(config, "Number");
+    const int n = group.readEntry("NumberOfWindows", 1);
     return number >= 1 && number <= n;
 }
 
@@ -391,15 +417,12 @@ const QString KMainWindow::classNameOfToplevel(int number)
     if (!config) {
         return QString();
     }
-    QString s;
-    s.setNum(number);
-    s.prepend(QStringLiteral("WindowProperties"));
 
-    KConfigGroup group(config, s);
-    if (!group.hasKey(QStringLiteral("ClassName"))) {
+    KConfigGroup group(config, QByteArray(WINDOW_PROPERTIES).append(QByteArray::number(number)).constData());
+    if (!group.hasKey("ClassName")) {
         return QString();
     } else {
-        return group.readEntry(QStringLiteral("ClassName"));
+        return group.readEntry("ClassName");
     }
 }
 
@@ -425,7 +448,11 @@ void KMainWindow::setCaption(const QString &caption)
 
 void KMainWindow::setCaption(const QString &caption, bool modified)
 {
-    setPlainCaption(caption);
+    QString title = caption;
+    if (!title.contains(QStringLiteral("[*]")) && !title.isEmpty()) { // append the placeholder so that the modified mechanism works
+        title.append(QStringLiteral(" [*]"));
+    }
+    setPlainCaption(title);
     setWindowModified(modified);
 }
 
@@ -486,10 +513,7 @@ void KMainWindow::savePropertiesInternal(KConfig *config, int number)
     const bool oldASWS = d->autoSaveWindowSize;
     d->autoSaveWindowSize = true; // make saveMainWindowSettings save the window size
 
-    QString s;
-    s.setNum(number);
-    s.prepend(QStringLiteral("WindowProperties"));
-    KConfigGroup cg(config, s);
+    KConfigGroup cg(config, QByteArray(WINDOW_PROPERTIES).append(QByteArray::number(number)).constData());
 
     // store objectName, className, Width and Height  for later restoring
     // (Only useful for session management)
@@ -498,8 +522,7 @@ void KMainWindow::savePropertiesInternal(KConfig *config, int number)
 
     saveMainWindowSettings(cg); // Menubar, statusbar and Toolbar settings.
 
-    s.setNum(number);
-    cg = KConfigGroup(config, s);
+    cg = KConfigGroup(config, QByteArray::number(number).constData());
     saveProperties(cg);
 
     d->autoSaveWindowSize = oldASWS;
@@ -531,7 +554,6 @@ void KMainWindow::saveMainWindowSettings(KConfigGroup &cg)
 
     QMenuBar *mb = internalMenuBar(this);
     if (mb) {
-        const QString MenuBar = QStringLiteral("MenuBar");
         if (!cg.hasDefault("MenuBar") && !mb->isHidden()) {
             cg.revertToDefault("MenuBar");
         } else {
@@ -550,12 +572,12 @@ void KMainWindow::saveMainWindowSettings(KConfigGroup &cg)
 
     int n = 1; // Toolbar counter. toolbars are counted from 1,
     foreach (KToolBar *toolbar, toolBars()) {
-        QString group(QStringLiteral("Toolbar"));
+        QByteArray groupName("Toolbar");
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
-        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QLatin1Char(' ') + toolbar->objectName());
+        groupName += (toolbar->objectName().isEmpty() ? QByteArray::number(n) : QByteArray(" ").append(toolbar->objectName().toUtf8()));
 
-        KConfigGroup toolbarGroup(&cg, group);
+        KConfigGroup toolbarGroup(&cg, groupName.constData());
         toolbar->saveSettings(toolbarGroup);
         n++;
     }
@@ -573,11 +595,7 @@ bool KMainWindow::readPropertiesInternal(KConfig *config, int number)
     }
 
     // in order they are in toolbar list
-    QString s;
-    s.setNum(number);
-    s.prepend(QStringLiteral("WindowProperties"));
-
-    KConfigGroup cg(config, s);
+    KConfigGroup cg(config, QByteArray(WINDOW_PROPERTIES).append(QByteArray::number(number)).constData());
 
     // restore the object name (window role)
     if (cg.hasKey("ObjectName")) {
@@ -588,8 +606,7 @@ bool KMainWindow::readPropertiesInternal(KConfig *config, int number)
     // if necessary. Do it before the call to applyMainWindowSettings.
     applyMainWindowSettings(cg); // Menubar, statusbar and toolbar settings.
 
-    s.setNum(number);
-    KConfigGroup grp(config, s);
+    KConfigGroup grp(config, QByteArray::number(number).constData());
     readProperties(grp);
 
     d->letDirtySettings = oldLetDirtySettings;
@@ -608,47 +625,40 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg)
     d->letDirtySettings = false;
 
     if (!d->sizeApplied) {
+        winId(); // ensure there's a window created
         KWindowConfig::restoreWindowSize(windowHandle(), cg);
+        // NOTICE: QWindow::setGeometry() does NOT impact the backing QWidget geometry even if the platform
+        // window was created -> QTBUG-40584. We therefore copy the size here.
+        // TODO: remove once this was resolved in QWidget QPA
+        resize(windowHandle()->size());
         d->sizeApplied = true;
     }
 
     QStatusBar *sb = internalStatusBar(this);
     if (sb) {
         QString entry = cg.readEntry("StatusBar", "Enabled");
-        if (entry == QStringLiteral("Disabled")) {
-            sb->hide();
-        } else {
-            sb->show();
-        }
+        sb->setVisible( entry != QLatin1String("Disabled") );
     }
 
     QMenuBar *mb = internalMenuBar(this);
     if (mb) {
         QString entry = cg.readEntry("MenuBar", "Enabled");
-        if (entry == QStringLiteral("Disabled")) {
-            mb->hide();
-        } else {
-            mb->show();
-        }
+        mb->setVisible( entry != QLatin1String("Disabled") );
     }
 
     if (!autoSaveSettings() || cg.name() == autoSaveGroup()) {   // TODO should be cg == d->autoSaveGroup, to compare both kconfig and group name
         QString entry = cg.readEntry("ToolBarsMovable", "Disabled");
-        if (entry == QStringLiteral("Disabled")) {
-            KToolBar::setToolBarsLocked(true);
-        } else {
-            KToolBar::setToolBarsLocked(false);
-        }
+        KToolBar::setToolBarsLocked(entry == QLatin1String("Disabled"));
     }
 
     int n = 1; // Toolbar counter. toolbars are counted from 1,
     foreach (KToolBar *toolbar, toolBars()) {
-        QString group(QStringLiteral("Toolbar"));
+        QByteArray groupName("Toolbar");
         // Give a number to the toolbar, but prefer a name if there is one,
         // because there's no real guarantee on the ordering of toolbars
-        group += (toolbar->objectName().isEmpty() ? QString::number(n) : QLatin1Char(' ') + toolbar->objectName());
+        groupName += (toolbar->objectName().isEmpty() ? QByteArray::number(n) : QByteArray(" ").append(toolbar->objectName().toUtf8()));
 
-        KConfigGroup toolbarGroup(&cg, group);
+        KConfigGroup toolbarGroup(&cg, groupName.constData());
         toolbar->applySettings(toolbarGroup);
         n++;
     }
@@ -669,14 +679,14 @@ void KMainWindow::applyMainWindowSettings(const KConfigGroup &cg)
     d->letDirtySettings = oldLetDirtySettings;
 }
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
 void KMainWindow::restoreWindowSize(const KConfigGroup &cg)
 {
     KWindowConfig::restoreWindowSize(windowHandle(), cg);
 }
 #endif
 
-#ifndef KDE_NO_DEPRECATED
+#ifndef KXMLGUI_NO_DEPRECATED
 void KMainWindow::saveWindowSize(KConfigGroup &cg) const
 {
     KWindowConfig::saveWindowSize(windowHandle(), cg);
